# SUL UI
SUL UI is designed to provide a solid foundation for websites and applications. With a primary goal to standardize components across projects.

Core Principles:
* Each component is simple and intuitive
* Each component is 100% tested
* Each component is responsive
* Each component is well defined with design, ux and development documentation

## Install
```sh
$ npm install @sul/ui
```
## Usage
SUL UI is designed to be simple. Each component is built to work in isolation and self-supporting.

### Quick Start
```javascript
import React from 'react';
import ReactDOM from 'react-dom';
import { ThemeProvider, Button } from '@sul/ui';

const App = () => (
  <ThemeProvider>
    <Button>Hello World</Button>
  </ThemeProvider>
);

ReactDOM.render(<App />, document.querySelector('#app'));
```
## Component Status

__Current Version: Pre-Release v0.2.0__

SUL UI is a living, breathing system that will grow with our needs. Here you'll find the ongoing status of our system. __Stable__ signifies the component is ready to be used in a production environment. __Experimental__ components, designs and other resources are presented for testing and feedback. They're not intended for production use. 

### Elements
Provide basic building blocks. These are typically low-level presentational components.

| Component | Stable | Experimental |
| --- | --- | --- |
| Anchor | &#10003; | - |
| Button | &#10003; | - |
| Divider | &#10003; | - |
| Heading | &#10003; | - |
| Image | &#10003; | - |
| Lead | &#10003; | - |
| List | &#10003; | - |
| MailTo | &#10003; | - |
| Paragraph | &#10003; | - |

### Layout
Provide or manipulate structure in some way.

| Component | Stable | Experimental |
| --- | --- | --- |
| Article | &#10003; | - |
| Box | &#10003; | - |
| Container | &#10003; | - |
| Flex | &#10003; | - |
| Grid | &#10003; | - |
| Hide | &#10003; | - |
| Section | &#10003; | - |
| Split | &#10003; | - |

### Modules
Modules are lower-level functional utilities or components. Typically these are extended and used in presentational
level components.

| Component | Stable | Experimental |
| --- | --- | --- |
| Layer | &#10003; | - |

### Patterns
Provide advanced layout and additional functionality. These components are typically more opinionated on structure.

| Component | Stable | Experimental |
| --- | --- | --- |
| Copyright | &#10003; | - |
| MobileNavigation | &#10003; | - |

### Utilities

| Utility | Stable | Experimental |
| --- | --- | --- |
| Breakpoint | &#10003; | - |
| Spacing | &#10003; | - |
| Text | &#10003; | - |

### Tag Descriptions

| Tag | Name | Definition
| --- | --- | --- |
| &#10003; | Ready | The component is design and dev ready |
| &#x26A0; | Under Review | Indicates that a component’s design, code, or usage is being re-examined or created. |
| X | Deprecated | Deprecated components have either been completely replaced by new components or are no longer being supported in the component library. |
| (New) | | This component is brand new to SUL UI |
| (Updated) | | Applied only to existing components after they have been under review, tweaked, and re-released to the design system.

## Contributing
Please read [CONTRIBUTING.md](https://github.com/sulweb/sul-ui/blob/master/CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/sulweb/sul-ui/tags).

Please read [CHANGELOG.md](https://github.com/sulweb/sul-ui/blob/master/CHANGELOG.md) for detailed changes to this project.

## Authors

* **Andrew Smith** - *Initial work* - [Stiff Upper Lip](https://github.com/sulweb)

## License

This project is licensed under the MIT License - see the [LICENSE.md](https://github.com/sulweb/sul-ui/blob/master/LICENSE.md) file for details.